# exo

A python package to make your API and JSON handling seemless. 
Get data from an API using our api handling tools, and then parse the api using our json tools.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install exo.

```bash
pip install exo-pyface
```

## Usage
Import `exo` as given in the examples in your python file.

Examples of usage:

```python
import exo
from exo import *
from exo import api
from exo import json as js
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
exo is licensed under GNU-3.0. Check the LICENSE file for more details. 